==> platon-6.2.tar.gz: platon-6.2/README.md <==
# PLanetary Atmospheric Transmission for Observer Noobs
<img src="logo.png" height="315">

 [![codecov](https://codecov.io/gh/ideasrule/platon/branch/devel/graph/badge.svg)](https://codecov.io/gh/ideasrule/platon)
[![arXiv](http://img.shields.io/badge/arXiv-2004.09513-orange.svg)](https://arxiv.org/abs/2004.09513) 
[![arXiv](http://img.shields.io/badge/arXiv-1811.11761-orange.svg)](https://arxiv.org/abs/1811.11761)

**Oct 30, 2024: PLATON v6.2 is out, with major updates!  This corresponds most closely to the version described in Zhang et al 2024.  Major changes include GPU support, free retrievals, surface emission, higher-resolution (R=20k) and more up-to-date opacities, leave-one-out cross-validation, pymultinest, and much better plotting tools.**

**February 2, 2020: PLEASE re-clone your repository if you cloned it before this
date!  On this date, all data files were deleted from the repository, including
from its history.  This shrank the repository's size from 1.2 GB to 36 MB,
which respects GitHub's size limit.**

**November 29, 2018: PLATON v3.0 is out!  Please check the release notes on GitHub for the list of new features.  Our paper actually describes v2.1, but v3 has a substantial number of improvements, and we strongly recommend everyone use it.**

**NEW (October 1): Version 2 is out, with a huge number of changes! Make sure to check out the release notes, and upgrade.**

PLATON is a fast and easy to use forward modelling and retrieval tool for
exoplanet atmospheres. It was written by Michael Zhang and Yayaati Chachan, and
is based on ExoTransmit by Eliza Kempton.

We welcome any feedback. Please send any comments, suggestions, or bug reports
to Michael Zhang: zmzhang "at" caltech.edu
**
To find installation instructions and quickstart examples, read the
documentation at: https://platon.readthedocs.io

*Now, these points of data  
make a beautiful line  
And we're out of beta  
We're releasing on time!*

==> platon-6.2.2.tar.gz: platon-6.2.2/README.md <==
# PLanetary Atmospheric Transmission for Observer Noobs
<img src="logo.png" height="315">

 [![codecov](https://codecov.io/gh/ideasrule/platon/branch/devel/graph/badge.svg)](https://codecov.io/gh/ideasrule/platon)
[![arXiv](http://img.shields.io/badge/arXiv-2004.09513-orange.svg)](https://arxiv.org/abs/2004.09513) 
[![arXiv](http://img.shields.io/badge/arXiv-1811.11761-orange.svg)](https://arxiv.org/abs/1811.11761)

**Oct 30, 2024: PLATON v6.2 is out, with major updates!  This corresponds most closely to the version described in [Zhang et al 2024](https://arxiv.org/abs/2410.22398).  Major changes include GPU support, free retrievals, surface emission, higher-resolution (R=20k) and more up-to-date opacities, leave-one-out cross-validation, pymultinest, and much better plotting tools.**

**February 2, 2020: PLEASE re-clone your repository if you cloned it before this
date!  On this date, all data files were deleted from the repository, including
from its history.  This shrank the repository's size from 1.2 GB to 36 MB,
which respects GitHub's size limit.**

**November 29, 2018: PLATON v3.0 is out!  Please check the release notes on GitHub for the list of new features.  Our paper actually describes v2.1, but v3 has a substantial number of improvements, and we strongly recommend everyone use it.**

**NEW (October 1): Version 2 is out, with a huge number of changes! Make sure to check out the release notes, and upgrade.**

PLATON is a fast and easy to use forward modelling and retrieval tool for
exoplanet atmospheres. It was written by Michael Zhang and Yayaati Chachan, and
is based on ExoTransmit by Eliza Kempton.

We welcome any feedback. Please send any comments, suggestions, or bug reports
to Michael Zhang: zmzhang "at" caltech.edu
**
To find installation instructions and quickstart examples, read the
documentation at: https://platon.readthedocs.io

*Now, these points of data  
make a beautiful line  
And we're out of beta  
We're releasing on time!*
